function [vcc_lim, mpc] = Vcc(mpc)

% This function allows to find the suspitious value of Vcc%(<4% or >30%) in
% each transformer, and provide a warning message in cases where these anomalies are found

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX BRIDGE, SHIFT_LIM,  R, X, B, B_pos, vcc_lim, Io_lim, voltage_diff,  lR, lX, lB, Zo, type, n_cond, length, section, nom_pow] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;


for i=1:length(mpc.branch(:,F_BUS))
    
    if mpc.branch(i,nom_pow)~=0
    S_base=10^6.*mpc.baseMVA;
    V_base=1000.*mpc.bus(i,BASE_KV);
    
    Vhv =V_base.*max(mpc.bus(mpc.branch(i,F_BUS),VM),mpc.bus(mpc.branch(i,T_BUS),VM));
    z_base=V_base^2./S_base;
    vcc_perc=100*((mpc.branch(i,BR_X).*z_base).*(S_base.*(mpc.branch(i,nom_pow))./(Vhv.^2.*V_base))); 
    
    if (vcc_perc(i)<4 | vcc_perc(i)>30)& mpc.branch(i,TAP)~=0
        mpc.branch(i,vcc_lim)= 1;
        
    elseif mpc.branch(i,TAP)==0
        
        mpc.branch(i,vcc_lim)=NaN;
        
    else
        mpc.branch(i,vcc_lim)=0;
        
    end
    
    if  mpc.branch(i,vcc_lim)==1
        warning('The estimated vcc% of the (%f) transformer is outside of a typical range of values (4% - 30%)', i);
    end
    else
        warning('Is not possible to do vcc% test because the rated power of the transformer is not known'); 
    end
end
end