function [bridge_branch, mpc] = bridge_identifications(mpc)

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX, BRIDGE] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

% This function allows to find the bridge.
% A bridge is a branch that increases the number of islands if it is removed.

for i= 1:length(mpc.branch(:,F_BUS)) %for each branch, if the status is active, it is deactivated and the number of islands is checked.
    if mpc.branch(i,BR_STATUS)==1
        mpc.branch(i,BR_STATUS)=0;
        n_islands = find_islands(mpc);
        if numel(n_islands) > 1     % if the number of islands increases after set the branch state to 0
            % it means that this branch is a bridge.
            mpc.branch(i,BRIDGE)=1; % the branch flag corresponding to the bridge column is set to 1
        else
            mpc.branch(i,BRIDGE)=0;
        end
        
        mpc.branch(i,BR_STATUS)=1;  % finally the branch is reset to the initial state
    end
end

bridge_branch =mpc.branch(:,BRIDGE); % Vector of 0 and 1 to identifie bridge_branch

active_branch = mpc.branch(mpc.branch(:,BR_STATUS)==1,:);

% for l=1:length(mpc.branch(:,F_BUS))
%     
%     if mpc.branch(l,BR_STATUS)==0
%         active_branch(l,:) = [];%This line of code allows you to delete the line
%         %corresponding to the branch that has been taken out of service
%         %from the matrix active_branch
%     end
% end

F = (active_branch(:,F_BUS)).'; %conversion of a column vector F_BUS in a row vector
T = (active_branch(:,T_BUS)).'; %conversion of a column vector F_BUS in a row vector
G=graph(T,F);
%adjacency_matrix=adjacency(G);
figure;
h= plot(G);
brg=find(bridge_branch);
bridge_nodes = union(mpc.branch(brg,F_BUS),mpc.branch(brg,T_BUS));
highlight(h,bridge_nodes,'NodeColor','g','EdgeColor','g');
end