function [leafnodes, mpc]  = find_terminal(mpc)

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
   TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX] = idx_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

%  This function allows you to identify the terminal nodes
%  searching for nodes that appear only in the column of the End buses
%  and never in the send buses and viceversa.
%  Generation nodes are not considered leaf nodes.

To_bus= mpc.branch(:,T_BUS);
From_bus = mpc.branch(:,F_BUS);
Gen_bus= mpc.gen(:,GEN_BUS);
presumed_leaf= vertcat(setdiff(From_bus,To_bus),setdiff(To_bus,From_bus));
%This line of code allows the union in a single vector
%of the nodes that appear only in the column of arrival nodes
%and those that appear only as starting nodes.

leafnodes=setdiff(presumed_leaf,Gen_bus);

mpc.bus(:,LEAF)=ismember(mpc.bus(:,BUS_I),leafnodes);

%check that the identified leaf nodes are not generation nodes,
%otherwise they should not be considered as terminal nodes.


%% plot of the network hilighting the leaf nodes
active_branch = mpc.branch(mpc.branch(:,BR_STATUS)==1,:);

F= (active_branch(:,F_BUS)).'; %conversion of a column vector F_BUS in a row vector
T= (active_branch(:,T_BUS)).'; %conversion of a column vector F_BUS in a row vector


%F= (mpc.branch(:,F_BUS)).'; %conversion of a column vector F_BUS in a row vector
%T= (mpc.branch(:,T_BUS)).'; %conversion of a column vector F_BUS in a row vector
G=graph(T,F);
%adjacency_matrix=adjacency(G);
figure;
h= plot(G);
highlight(h,leafnodes,'NodeColor','g')
end