function [voltage_diff, mpc] = from_to_voltage(mpc)

% This function allows to find the suspitious difference of rated voltage between from and to bus.
% Because if it is a line, the nominal voltage value between the two ends must necessarily be the same

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX BRIDGE, SHIFT_LIM, R, X, B, B_neg, vcc_lim, Io_lim, voltage_diff] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;


lines_branches=mpc.branch(:,TAP)==0;
transf_branches=mpc.branch(:,TAP)~=0;

F_BUS_voltage = mpc.bus(mpc.branch(lines_branches,F_BUS),VM);
T_BUS_voltage = mpc.bus(mpc.branch(lines_branches,T_BUS),VM);

threshold= 0.1; % impose a threshold of 10% of difference between from voltage and to voltage
mpc.branch(lines_branches,voltage_diff)= abs(F_BUS_voltage-T_BUS_voltage)>threshold;
mpc.branch(transf_branches,voltage_diff)= NaN;
%mpc.branch(2,voltage_diff)=1; messo questa linea per verificare il
%corretto funzionamento del warning
F_T_bus =mpc.branch(lines_branches,voltage_diff);
flag_F_T=any(F_T_bus);
if flag_F_T==1
    warning('there is at least one line with a different rated voltage between the departure node and the arrival node');
end
voltage_diff=abs(F_BUS_voltage-T_BUS_voltage);
end