function [Lresistance, Lreactance, Lsusceptance, mpc] = line_R_X_B(mpc)

% This function allows to find the suspitious value of R,X,B in each line branch.
% if the line is considered suspicious, a warning message will be displayed 
% and a 1 will be saved in the dedicated column of the output matrix

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX BRIDGE, SHIFT_LIM, R, X, B, B_neg, vcc_lim, Io_lim, voltage_diff, lR, lX, lB] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

% 

lines_branches=mpc.branch(:,TAP)==0;
transf_branches=mpc.branch(:,TAP)~=0;

mpc.branch(transf_branches,lR)=NaN;
mpc.branch(transf_branches,lX)=NaN;
mpc.branch(transf_branches,lB)=NaN;

suspicious_case_R= mpc.branch(:,BR_R)==0 | mpc.branch(:,BR_R)==0.100 | mpc.branch(:,BR_R)==0.0100 | mpc.branch(:,BR_R)==0.00100 | isnan(mpc.branch(:,BR_R));
suspicious_case_X= mpc.branch(:,BR_X)==0 | mpc.branch(:,BR_X)==0.100 | mpc.branch(:,BR_X)==0.0100 | mpc.branch(:,BR_X)==0.00100 | isnan(mpc.branch(:,BR_X));
suspicious_case_B= mpc.branch(:,BR_B)==0 | mpc.branch(:,BR_B)==0.100 | mpc.branch(:,BR_B)==0.0100 | mpc.branch(:,BR_B)==0.00100 | isnan(mpc.branch(:,BR_B));

if any(suspicious_case_R==1)
    mpc.branch(suspicious_case_R,lR)=1;
    mpc.branch(transf_branches,lR)=NaN;
elseif  lines_branches
    mpc.branch(lines_branches,lR)=0;
end
Lresistance=mpc.branch(lines_branches,lR);

if any(suspicious_case_X==1)
    mpc.branch(suspicious_case_X,lX)=1;
    mpc.branch(transf_branches,lX)=NaN;
elseif  lines_branches
    mpc.branch(lines_branches,lX)=0;
end
Lreactance=mpc.branch(lines_branches,lX);

if any(suspicious_case_B==1)
    mpc.branch(suspicious_case_B,lB)=1;
    mpc.branch(transf_branches,lB)=NaN;
elseif  lines_branches
    mpc.branch(lines_branches,lB)=0;
end
Lsusceptance=mpc.branch(lines_branches,lB);

R0 =  mpc.branch(:,lR);

flag_R=any(R0);

if flag_R==1
    warning('There are one or more suspected line resistance values');
end

X0 =  mpc.branch(:,lX);

flag_X=any(X0);

if flag_X==1
    warning('There are one or more suspected line reactance values');
end

B0 =  mpc.branch(:,lB);

flag_B=any(B0);

if flag_B==1
    warning('There are one or more suspected line susceptance values');
end
%return 1 if value is sospicious or 0 otherwhise, NaN when the branch is a transformer branch
end