clear
close all
clc
%% SETTINGS

flag_islands=1;
flag_leaf_nodes=1;
flag_branch_bridge=1;
flag_power_balance=1;
flag_shift=1;
flag_transformers_R_X_B=1;
flag_sign_susceptance=0;
flag_vcc=0;
flag_Io=0;
flag_voltage_diff=1;
flag_line_R_X_B=0;
flag_line_Zo=0;
length_flag=0;
section_flag=0;

epsilon=20; %power balance threshold

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX, BRIDGE, SHIFT_LIM] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

%% MAKING CASE STUDY-TEMPORARY


% mpc = loadcase('case9');
% 
%  % to test leaf_nodes
%  mpc.branch(10,:)=mpc.branch(9,:);
%  mpc.branch(10,F_BUS)= 9;
%  mpc.branch(10,T_BUS)= 10;
%  mpc.bus(10,:)=mpc.bus(9,:);
%  mpc.bus(10,BUS_I)= 10; %I add a terminal node manually
%  
% % to test branch_bridge function
%  mpc.branch(9,BR_STATUS)=0; %set to 0 the status of the branch that connect bus 4 to bus 9 
%                             %To test the correct execution of the function
%  % to test vcc function
%   mpc.branch([1 3 7 10],TAP)=0.95;  

mpc = loadcase('case2383wp');
tic
active_branch = mpc.branch(mpc.branch(:,BR_STATUS)==1,:);


F= (active_branch(:,F_BUS)).'; %conversion of a column vector F_BUS in a row vector
T= (active_branch(:,T_BUS)).'; %conversion of a column vector F_BUS in a row vector
G=graph(T,F);
figure;
h= plot(G);
 %% PROCESSING

 % This function allows you to check if there is more than one island in the network
 if flag_islands==1
     [num_island, mpc] = find_island(mpc);
 end
 
% The function identifies the load terminal nodes
 if flag_leaf_nodes==1
     [leafnodes, mpc] = find_terminal(mpc);
 else
     mpc.bus(:,LEAF)= NaN;
 end

% The function identifies bridges 
 if flag_branch_bridge==1
     [bridge_branch, mpc] = bridge_identifications(mpc);
 else
     mpc.branch(:,BRIDGE)= NaN;
 end

 % The function makes the balance between the power produced and the power on the loads,
 % verifying if the difference is greater than the epsilon threshold
 if flag_power_balance==1
     [mpc] = make_power_balance(mpc, epsilon); 
 end
 
 %The function makes the difference between voltage phase of 'from' and 'to' bus,
 % verifying if the difference is greater than the threshold of 10 degrees
 if flag_shift==1
     results = rundcpf(mpc); 
     
     [phase_shift, mpc] = phase_differences(mpc, results);
     
 else
     mpc.branch(:,SHIFT_LIM)=NaN;
 end
 
%% TRANSFORMERS

%The function checks for the presence of suspicious values of R, X, B for the transformers,
%in case of lines it returns NaN
if flag_transformers_R_X_B==1
[resistance, reactance, susceptance, mpc] = transformer_R_X_B(mpc);
end

% This function allows to find the suspitious value of B in each transformer branch analyzing the susceptance sign
if flag_sign_susceptance==1
[positive_susceptance, mpc] = susceptance_sign(mpc); % i valori di suscettanza B sono tutti positivi, verifico correttezza?
end

%This function allows to calculate the Vcc% values of the transformers and identify suspicious ones
if flag_vcc==1   
[vcc_lim, mpc] = Vcc(mpc);% codice funziona unico problema potenza sempre 0 quindi da tutte le vcc=0 potenza non  quella da prendere
end

%This function allows to calculate the I0% values ??of the transformers and identify suspicious ones
if flag_Io==1
[Io_lim, mpc] = Io_transformer(mpc); % codice funziona unico problema potenza sempre 0 e CALCOLO DI IO%  giusto??
end

%% LINES

%This function allows to identify suspected voltage differences between the departure and arrival bus of a line
if flag_voltage_diff==1
    if exist('results', 'var')==0
    results = rundcpf(mpc);
    end
    [voltage_diff, mpc] = from_to_voltage(mpc); 
end

% This function allows to find the suspitious value of R,X,B in each line branch. 
if flag_line_R_X_B==1
    [Lresistance, Lreactance, Lsusceptance, mpc] = line_R_X_B(mpc);
end

% This function allows to calculate Zo and, in relation to its value, to identify the type of line
if flag_line_Zo==1
    [Zo_values, mpc] = Zo_calculation(mpc);
end

%This function allows to calculate the length in relation to the Zo values obtained
if length_flag==1
[lines_length, mpc] = length_estimation(mpc);
end

%This function allows to estimate the section in relation to the Zo values obtained
if section_flag==1
[estim_section, mpc] = section_estimation(mpc, lines_length); %sembra funzionarea a parte valori lines_length
end
toc