function [mpc] = make_power_balance(mpc, epsilon)

% This function allows you to identify anomalies and excessive differences
% between the power generated and the power of the loads in the network

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX BRIDGE,] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

P_gen= sum(mpc.gen(:,PG),1);
P_load= sum(mpc.bus(:,PD),1);
PB=(P_gen-P_load)/P_load*100;
if PB>epsilon % if the power difference is greater than a threshold, a warning message will be returned
    warning('The difference between the total injected power(%f) and the total power demand(%f) is greater than the set threshold(%f)',P_gen, P_load, epsilon);
end
end