function [phase_shift, mpc] = phase_differences (mpc, results)

% This function allows you to identify the branches that have a difference
% between the voltage phase at the beginning and end of the line greater than 10 degrees
% and provide a warning message for the corresponding branches

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX, BRIDGE, SHIFT_LIM] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

% This function allows to identify anomalous phase shifts
% between "from" and "to" bus.

Va_FB= results.bus(results.branch(:,F_BUS),VA);
Va_TB= results.bus(results.branch(:,T_BUS),VA);
deltaVa=(Va_FB-Va_TB);

% deltaVa([2,7],1)=30; This two lines are used to verify the correct operation of the function code
%deltaVa([4,9],1)=-30;

p_s_lim=10;
mpc.branch(:,SHIFT_LIM)=abs(deltaVa)>p_s_lim; %abs return 1 if the condition >10 is true or 0 otherwhise

phase_shift =  mpc.branch(:,SHIFT_LIM);
flag_shift=any(phase_shift);

if flag_shift==1
    warning('The difference between the phase of from bus voltage and the phase of to bus voltage is greater than the set threshold(%f)', p_s_lim);
end
% the function will return a vector with the numbers of the branches (the rows of the matrix)
% where the phase shifts between "from" and "to" bus" is greater than 10 degrees.
end