function [positive_susceptance, mpc] = susceptance_sign(mpc)

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX BRIDGE, SHIFT_LIM, R, X, B, B_pos] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

% This function allows to find the suspitious value of B in each transformer branch analyzing the susceptance sign.

transformer_branches = mpc.branch(:,TAP)~=0;
positive_susceptance = mpc.branch(transformer_branches,BR_B)>0;
mpc.branch(transformer_branches,B_pos)= positive_susceptance;
mpc.branch(mpc.branch(:,TAP)==0,B_pos)= NaN; %if this row does not correspond to a transform it will return NaN

B_positive =  mpc.branch(:,B_pos);

flag_pos=any(B_positive);

if flag_pos==1
    warning('There are one or more positive susceptance values');
end
end