function [resistance, reactance, susceptance, mpc] = transformer_R_X_B(mpc)

% This function allows to find the suspitious value of R,X,B (for example null values)
% and provide a warning message for the affected transformers

%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
    VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN, LEAF] = id_bus;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX BRIDGE, SHIFT_LIM, R, X, B] = id_brch;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;

for i=1:length(mpc.branch(:,F_BUS))
    
    if mpc.branch(i,BR_R)==0
        mpc.branch(i,R)=1;
    elseif isnan ( mpc.branch(i,BR_R))
        mpc.branch(i,R)=1;
    else
        mpc.branch(i,R)=0;
        
        resistance=mpc.branch(i,R);
    end
    
    if mpc.branch(i,BR_X)==0
        mpc.branch(i,X)=1;
    elseif isnan(mpc.branch(i,BR_X))
        mpc.branch(i,X)=1;
    else
        mpc.branch(i,X)=0;
        
        reactance=mpc.branch(i,X);
    end
    
    if mpc.branch(i,BR_B)==0
        mpc.branch(i,B)=1;
    elseif isnan(mpc.branch(i,BR_B))
        mpc.branch(i,B)=1;
    else
        mpc.branch(i,B)=0;
        
        susceptance = mpc.branch(i,B);
    end
    
    if mpc.branch(i,TAP)==0
        mpc.branch(i,R)=NaN;
        mpc.branch(i,X)=NaN;
        mpc.branch(i,B)=NaN;
        resistance=mpc.branch(i,R);
        reactance=mpc.branch(i,X);
        susceptance=mpc.branch(i,B);
    end    
end
%return 1 if value is sospicious or 0 otherwhise in 3 different column
R0 =  mpc.branch(:,R);

flag_R=any(R0);

if flag_R==1
    warning('There are one or more suspected resistance values');
end

X0 =  mpc.branch(:,X);

flag_X=any(X0);

if flag_X==1
    warning('There are one or more suspected reactance values');
end

B0 =  mpc.branch(:,B);

flag_B=any(B0);

if flag_B==1
    warning('There are one or more suspected susceptance values');
end
end